calcDegradationYieldReduction
Source:R/calcDegradationYieldReduction.R
calcDegradationYieldReduction.RdFunction creates dummy file for including yield reduction coefficients to represent land degradation
R/calcDegradationYieldReduction.R
calcDegradationYieldReduction.RdFunction creates dummy file for including yield reduction coefficients to represent land degradation