Skip to content

calculates Soil Organic Matter Pool, accounting for the management history as initialisation to magpie

Usage

calcSOMinitialsiationPools(cells = "lpjcell")

Arguments

cells

"magpiecell" for 59199 cells or "lpjcell" for 67420 cells

Value

List of magpie object with results on country or cellular level, weight on cellular level, unit and description.

Author

Benjamin Leon Bodirsky, Kristine Karstens

Examples

if (FALSE) { # \dontrun{
calcOutput("SOMinitialsiationPools")
} # }