Download the critical nitrogen surplus values of Schulte-Uebbing et al. 2022. This function requires the 'archive' package, which is suggested. If 'archive' is not available, the function will stop with an error.
Download the critical nitrogen surplus values of Schulte-Uebbing et al. 2022. This function requires the 'archive' package, which is suggested. If 'archive' is not available, the function will stop with an error.